DOCUMENTATION FOR COAX TRAP PROGRAM - 12/29/93

This program is of interest to Amateur Radio operators.  It was originally written by Andy Griffith, W4ULD.  It's been adapted to the Model 100 and experimentally verified (at 18.084 MHz) for accuracy by Ron Wiesen, WD8PNL.

The program lets you model antenna traps that are made of coaxial cable that's wound on a form.  Results can be directed to the screen or to a printer.  You model traps via four inputs to the program: Coax Diameter, Coax Capacitance per foot, Form Diameter, and Frequency.  The program produces results and then allows you to alter all or some of the inputs, or to exit.

Coax Diameter and Coax Capacitance per foot are physical properties of the particular coaxial cable that you intend to use.  Refer to the "Transmission Lines" chapter of the ARRL Handbook, or other publications, which list these properties for the common coaxial cable types.  Form Diameter is the input you are will alter most often during a modelling session because overall antenna efficiency depends upon it.  Of course you alter it according to whatever sizes of form material (PVC pipe, etc.) are handy.  You choose Frequency according to license privileges (Novice, Extra, etc.) for bands and according to the transmission modes (Exclusive Code, Code and Voice, etc.) for sub-bands.

The results are: Reactance (XL and XC), Inductance (L), Capacitance (C), Number of Turns, Winding Length, Coax Length, and Effective Length.  If your modelling objective is best overall antenna efficiency (high Q traps), strive for more reactance with shorter coax length.

What follows is a brief explanation of coaxial cable traps and related Amateur Radio publication references, figures that show physical trap construction and related electrical properties, practical tips, and tabulated model data with extra information (form factor and Q).  The tabulated data covers a family of traps centered on the Exclusive Code sub-band in each of the 40, 30, 20, 17, 15, 12, and 10 meter Amateur Radio bands.

Compact antenna traps can be made from coaxial cable.  FIGURE 1 shows a trap with coax wound on a hollow form.  A wire jumper runs inside the form to connect one end of the inner conductor to the outer conductor at the opposite end of the form.  Such traps are described in Amateur Radio publications:

1.  R. Johns, "Coaxial Cable Antenna Traps," QST, May 1981, p. 15.

2.  G. O'Neil, "Trapping the Mysteries of Trapped Antennas," Ham Radio, October 1981, p. 10.

3.  The ARRL Handbook, chapter titled "Antenna Projects".

FIGURE 2 shows a typical trap antenna.  In FIGURE 3, trap capacitance (C) is simply the distributed capacitance of the coax.  Trap inductance (L) is the outer conductor inductance in series with the inner conductor inductance.  Three things are noteworthy:

1.  Because antenna segments appear at the ends of the outer conductor, parallel resonance with respect to these points is the trap frequency.

2.  Because adjacent turns are magnetically coupled, the inductance of the outer conductor is that of a conventional single-layer air-core winding.

3.  Because adjacent turns are magnetically shielded from each other, the inductance of the inner conductor is that of a straight wire in free space.  Compared to the inductance of the outer conductor, such a small inductance is negligible.

                                                            ''''} Antenna
                    Coax Winding                       +----@+    Terminal
                      +-----+         +-----+         / * * *|###
                     / * * * \       / * * * \       / * +---+   # jumper
==D=           ==== / * +========== / * +========== / * /=     # wire
F I            |   / * /           / * /           / * / |   # runs inside
O A   jumper ##|- / * / -   -   - / * / -   -   - / * / -|## hollow form
R M.    wire # | / * /           / * /           / * /   |
M===         # =/ * / ==========+ * / ==========+ * / ====
           +-@-+ * /       \ * * * /       \ * * * /
free end ##|* * * /         +-----/         +-----+
           +@----+
Antenna {''''         @ denotes solder joints
Terminal
                                 FIGURE 1

             28.150      21.100                               +-} Antenna {-+
o============{Trap}======{Trap}=========          +---------+ | +---------+ |
 Tri-Band Trap Antenna (1/4 wave shown)         +-+ L inner +-+-+ L outer +-+
                                                | +---------+   +---------+ |
<--28.150--->                                   |     +---------------+     |
<--21.100--------------->                       +-----+ C distributed +-----+
<--14.075------------------------------>              +---------------+
                FIGURE 2                                  FIGURE 3
                                                                                
A few practical tips are in order.  Only use coax with a solid dielectric, foam dielectric is not suitable.  Don't solder close to the dielectric.  Coax with a stranded inner conductor is preferred.  Secure the free end of the inner conductor within the form and far away from other conductors.  With the trap disconnected from the antenna, use a grid dip oscillator and spread or compress the spacing of the turns to adjust the trap frequency.  Coat the entire trap with silicone rubber to secure the windings and weatherproof the trap.

The Q of the coax trap is mostly limited by the Q of the inductance, so it's important to consider the geometry of the coax winding.  The ratio of it's length to it's diameter, called it's form factor, significantly affects the Q.  A rule of thumb is to keep the form factor between 3.00:1 and 0.25:1.  Form factors near 0.38 usually yield the highest Q and, generally, the highest antenna efficiency.

The program doesn't show the Q or the form factor (length/diameter) of the coax winding.  The form factor is easy to figure.  Because the coax is wound "on" the form, the diameter of the "coax winding" is the sum of the Form Diameter and the coax diameter.  Rather than figure the Q of a trap, just use the program for several traps of the same frequency and divide the reactance of each one by the length of coax needed to make it.  The trap with the highest result is the trap with the highest Q, but the result is not the actual Q.

Examples of traps made with RG-58 coax for several Amateur bands are listed below.  For each band, the Form Diameter increases by steps of 0.25 inch without exceeding a 3.00:1 to 0.25:1 range of form factors.  An asterisk (*) identifies the highest Q form in each band.  The actual Q of each trap is listed.

Specifications of RG-58 coax:
        0.195 inch diameter
        28.5 pf per foot.

RG-58 coax winding form factor = Winding Length / (Form Diameter + 0.195)

         7.075 MHz Trap

Form    Winding Coax    React-  Form
Diam.   Length  Needed  ance    Factor  Q
1.00    3.71    76.0    133.0   3.10:1  214.6
1.25    2.93    70.7    141.4   2.03:1  245.3
1.50    2.34    67.1    147.4   1.38:1  269.4
1.75    1.95    64.9    151.7   1.00:1  286.6
2.00    1.76    63.7    154.6   0.80:1  297.6
2.25 *  1.56    62.6    155.6   0.64:1  304.8

        10.125 MHz Trap

Form    Winding Coax    React-  Form
Diam.   Length  Needed  ance    Factor  Q
1.00    2.54    54.1    129.4   2.13:1  245.2
1.25    2.15    51.1    136.5   1.49:1  273.8
1.50    1.76    49.0    140.6   1.04:1  294.1
1.75    1.37    47.6    143.4   0.70:1  308.8
2.00    1.37    47.2    145.1   0.62:1  315.1
2.25 *  1.17    46.7    145.2   0.48:1  318.7

        14.075 MHz Trap

Form    Winding Coax    React-  Form
Diam.   Length  Needed  ance    Factor  Q
1.00    1.95    40.1    125.4   1.63:1  271.9
1.25    1.56    38.0    130.4   1.08:1  298.3
1.50    1.37    36.9    133.6   0.81:1  314.8
1.75    1.17    36.3    135.1   0.60:1  323.6
2.00 *  0.98    35.9    135.7   0.45:1  328.6
2.25    0.98    36.0    135.3   0.40:1  326.8

        18.084 MHz Trap

Form    Winding Coax    React-  Form
Diam.   Length  Needed  ance    Factor  Q
1.00    1.56    32.0    121.8   1.31:1  291.9
1.25    1.17    30.4    125.3   0.81:1  316.1
1.50    0.98    29.7    127.6   0.58:1  329.5
1.75    0.98    29.6    128.3   0.50:1  332.5
2.00 *  0.78    29.4    128.7   0.36:1  335.8
2.25    0.78    29.6    127.6   0.32:1  330.6

        21.100 MHz Trap

Form    Winding Coax    React-  Form
Diam.   Length  Needed  ance    Factor  Q
1.00    1.37    28.0    123.7   1.15:1  313.7
1.25    1.17    26.9    123.0   0.81:1  324.7
1.50    0.98    26.2    123.3   0.58:1  334.2
1.75 *  0.78    25.9    123.5   0.40:1  338.6
2.00    0.78    26.3    125.2   0.36:1  338.0
2.25    0.59    26.2    123.7   0.24:1  335.3

        24.910 MHz Trap

Form    Winding Coax    React-  Form
Diam.   Length  Needed  ance    Factor  Q
1.00    1.17    24.1    116.5   0.98:1  315.9
1.25    0.98    23.3    118.7   0.68:1  332.9
1.50 *  0.78    23.0    121.0   0.46:1  343.8
1.75    0.78    22.9    119.0   0.40:1  339.6
2.00    0.59    23.0    119.8   0.27:1  340.4
2.25    0.59    23.2    118.1   0.24:1  332.7

        28.150 MHz Trap

Form    Winding Coax    React-  Form
Diam.   Length  Needed  ance    Factor  Q
1.00    0.98    21.6    114.3   0.82:1  325.3
1.25    0.78    20.9    116.6   0.54:1  343.0
1.50    0.78    20.9    117.2   0.46:1  344.7
1.75 *  0.59    20.7    117.1   0.30:1  347.8
2.00    0.59    20.9    115.4   0.27:1  339.4
2.25    0.59    21.2    114.8   0.24:1  332.9


